Generate presentation images from a YAML configuration
Arguments
- path
Path to a YAML configuration file or a directory containing
bananarama.yaml. Defaults to"bananarama.yaml"in the current directory.- output_dir
Directory to save generated images, relative to the YAML configuration file (or an absolute path). Defaults to the
output-dirfield in the YAML file, or a directory with the same name as the YAML file (e.g.bananarama.yamloutputs tobananarama/).- force
If
TRUE, regenerate all images even if they already exist.